@@ -240,7 +240,7 @@ class TID3File(TestCase):
         f.tags.add(mutagen.id3.TCON(encoding=3, text=["4", "5"]))
         f.save()
         genres = set(MP3File(self.filename).list("genre"))
-        self.failUnlessEqual(genres, set(["Funk", "Disco"]))
+        self.failUnlessEqual(genres, {"Funk", "Disco"})
 
     def test_mb_track_id(self):
         f = mutagen.File(self.filename)
@@ -264,7 +264,7 @@ class TID3File(TestCase):
                                     desc="", text=["foo", "bar"]))
         f.save()
         comments = set(MP3File(self.filename).list("comment"))
-        self.failUnlessEqual(comments, set(["bar", "foo"]))
+        self.failUnlessEqual(comments, {"bar", "foo"})
 
     def test_foobar2k_replaygain(self):
         # foobar2k saved gain there
@@ -290,6 +290,14 @@ class TID3File(TestCase):
         # Others don't like RVA2, so we have to read/write foobar style
         # https://github.com/quodlibet/quodlibet/issues/1027
         f = mutagen.File(self.filename)
+
+        # use RVA2 in case it's the only one
+        f.tags.add(mutagen.id3.RVA2(desc="track", channel=1,
+                                    gain=-9, peak=1.0))
+        f.save()
+        song = MP3File(self.filename)
+        self.failUnlessAlmostEqual(song.replay_gain(["track"]), 0.35, 1)
+
         f.tags.add(mutagen.id3.TXXX(encoding=3, desc="replaygain_track_gain",
                                     text=["-6 db"]))
         f.tags.add(mutagen.id3.TXXX(encoding=3, desc="replaygain_track_peak",
@@ -306,13 +314,6 @@ class TID3File(TestCase):
         self.failUnlessEqual(song("replaygain_album_gain"), "3 db")
         self.failUnlessEqual(song("replaygain_album_peak"), "0.8")
 
-        # still prefer RVA2 in case there are both
-        f.tags.add(mutagen.id3.RVA2(desc="track", channel=1,
-                                    gain=-9, peak=1.0))
-        f.save()
-        song = MP3File(self.filename)
-        self.failUnlessAlmostEqual(song.replay_gain(["track"]), 0.35, 1)
-
     def test_foobar2k_replaygain_write_new(self):
         # Others don't like RVA2, so we have to read/write foobar style
         # https://github.com/quodlibet/quodlibet/issues/1027
@@ -327,6 +328,23 @@ class TID3File(TestCase):
         for k in ["track_peak", "track_gain", "album_peak", "album_gain"]:
             self.failUnless(f["TXXX:replaygain_" + k])
 
+    def test_foobar2k_rg_caseinsensitive(self):
+        f = mutagen.File(self.filename)
+        f.tags.add(mutagen.id3.TXXX(encoding=3, desc="REPLAYGAIN_TRACK_GAIN",
+                                    text=["-6 db"]))
+        f.save()
+        song = MP3File(self.filename)
+        self.failUnlessEqual(song("replaygain_track_gain"), "-6 db")
+        song.write()
+        f = mutagen.File(self.filename)
+        frames = f.tags.getall("TXXX:replaygain_track_gain")
+        self.assertTrue(frames)
+        self.assertEqual(frames[0].desc, "replaygain_track_gain")
+        del song["replaygain_track_gain"]
+        song.write()
+        f = mutagen.File(self.filename)
+        self.assertFalse(f.tags.getall("TXXX:replaygain_track_gain"))
+
     def test_quodlibet_txxx_inval(self):
         # This shouldn't happen in our namespace, but check anyway since
         # we might open the whole TXXX namespace sometime
@@ -351,7 +369,7 @@ class TID3File(TestCase):
         song = MP3File(self.filename)
         self.failIf("foo=" in song)
         self.failIf(u"öäü" in song)
-        self.failUnlessEqual(set(song.list("comment")), set(["a", "b"]))
+        self.failUnlessEqual(set(song.list("comment")), {"a", "b"})
         self.failUnlessEqual(song("valid"), "quux")
         del song["valid"]
         song.write()
