@@ -12,11 +12,11 @@ import tempfile
 import os
 import sys
 import threading
+import traceback
 import time
 from quodlibet import util
 from quodlibet import config
 from quodlibet.util import format_time_long as f_t_l
-from quodlibet.util.compat import text_type
 
 
 is_win = os.name == "nt"
@@ -675,7 +675,7 @@ class Tlibrary(TestCase):
 class TNormalizePath(TestCase):
 
     def test_default(self):
-        from quodlibet.util.path import _normalize_path as norm
+        from quodlibet.util.path import normalize_path as norm
 
         name = norm(tempfile.mkdtemp())
         try:
@@ -685,13 +685,10 @@ class TNormalizePath(TestCase):
             os.rmdir(name)
 
     def test_canonicalise(self):
-        from quodlibet.util.path import _normalize_path, _normalize_darwin_path
-        self._test_canonicalise(_normalize_path)
-        if sys.platform == "darwin":
-            self._test_canonicalise(_normalize_darwin_path)
+        from quodlibet.util.path import normalize_path as norm
 
-    def _test_canonicalise(self, norm):
         f, path = tempfile.mkstemp()
+        path = os.path.realpath(path)  # on osx tmp is a symlink
         os.close(f)
         path = norm(path)
 
@@ -1032,7 +1029,7 @@ class Tenum(TestCase):
     def test_main(self):
 
         @util.enum
-        class Foo(object):
+        class Foo(int):
             FOO = 0
             BAR = 1
 
@@ -1042,6 +1039,17 @@ class Tenum(TestCase):
         self.assertEqual(Foo.FOO, 0)
         self.assertEqual(Foo.BAR, 1)
 
+    def test_str(self):
+        @util.enum
+        class Foo(str):
+            FOO = "blah"
+            BAR = "foo"
+
+        self.assertTrue(issubclass(Foo, str))
+        self.assertTrue(isinstance(Foo.BAR, Foo))
+        self.assertEqual(Foo.FOO, "blah")
+        self.assertEqual(repr(Foo.BAR), "Foo.BAR")
+
 
 class Tlist_unique(TestCase):
 
@@ -1053,13 +1061,26 @@ class Tlist_unique(TestCase):
         self.assertEqual(util.list_unique([1, 1, 1, 2]), [1, 2])
 
 
-class Tset_win32_unicode_argv(TestCase):
+class Treraise(TestCase):
+
+    def test_reraise(self):
+        try:
+            try:
+                raise ValueError("foo")
+            except Exception as e:
+                util.reraise(TypeError, e)
+        except Exception as e:
+            self.assertTrue(isinstance(e, TypeError))
+            self.assertTrue("ValueError" in traceback.format_exc())
+        else:
+            self.assertTrue(False)
+
+
+class Tenviron(TestCase):
 
     def test_main(self):
-        old_argv = sys.argv
-        try:
-            util.set_win32_unicode_argv()
+        for v in util.environ.values():
             if os.name == "nt":
-                self.assertTrue(isinstance(sys.argv[0], text_type))
-        finally:
-            sys.argv = old_argv
+                self.assertTrue(isinstance(v, unicode))
+            else:
+                self.assertTrue(isinstance(v, str))
